@@ -4,6 +4,7 @@
 ffirst <- function(x, ...) UseMethod("ffirst") # , x
 
 ffirst.default <- function(x, g = NULL, TRA = NULL, na.rm = TRUE, use.g.names = TRUE, ...) {
+  if(is.matrix(x) && !inherits(x, "matrix")) return(ffirst.matrix(x, g, TRA, na.rm, use.g.names, ...))
   if(!missing(...)) unused_arg_action(match.call(), ...)
   if(is.null(TRA)) {
     if(is.null(g)) return(.Call(Cpp_ffirst,x,0L,0L,na.rm))
@@ -74,7 +75,7 @@ ffirst.data.frame <- function(x, g = NULL, TRA = NULL, na.rm = TRUE, use.g.names
       return(.Call(Cpp_ffirstl,x,attr(g,"N.groups"),g,na.rm))
     }
     if(!is.GRP(g)) g <- GRP.default(g, return.groups = use.g.names, call = FALSE)
-    if(use.g.names && !inherits(x, "data.table") && !is.null(groups <- GRPnames(g)))
+    if(use.g.names && !inherits(x, "data.table") && length(groups <- GRPnames(g)))
       return(setRnDF(.Call(Cpp_ffirstl,x,g[[1L]],g[[2L]],na.rm), groups))
     return(.Call(Cpp_ffirstl,x,g[[1L]],g[[2L]],na.rm))
   }
@@ -103,7 +104,7 @@ ffirst.grouped_df <- function(x, TRA = NULL, na.rm = TRUE, use.g.names = FALSE,
     attributes(x) <- NULL
     if(nTRAl) {
       ax[["groups"]] <- NULL
-      ax[["class"]] <- ax[["class"]][ax[["class"]] != "grouped_df"]
+      ax[["class"]] <- fsetdiff(ax[["class"]], c("GRP_df", "grouped_df"))
       ax[["row.names"]] <- if(use.g.names) GRPnames(g) else .set_row_names(g[[1L]])
       if(gl) {
         if(keep.group_vars) {
