@@ -1,8 +1,49 @@
+# Row-operations (documented under data transformations...) ... see if any other package has it (i.e. matrixStats etc..)
+# or wirhout r ??? look for %+% function on Rducumentation.. rdio.
+
+"%rr%" <- function(X, v) if(is.atomic(X) || is.atomic(v) || inherits(X, "data.frame")) TRA(X, v, "replace_fill") else # outer(rep.int(1L, dim(X)[2L]), v)
+  duplAttributes(mapply(function(x, y) TRA(x, y, "replace_fill"), unattrib(X), unattrib(v),
+                        USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%r+%" <- function(X, v) if(is.atomic(X) || is.atomic(v) || inherits(X, "data.frame")) TRA(X, v, "+") else
+  duplAttributes(mapply(function(x, y) TRA(x, y, "+"), unattrib(X), unattrib(v),
+                        USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%r-%" <- function(X, v) if(is.atomic(X) || is.atomic(v) || inherits(X, "data.frame")) TRA(X, v, "-") else
+  duplAttributes(mapply(function(x, y) TRA(x, y, "-"), unattrib(X), unattrib(v),
+                        USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%r*%" <- function(X, v) if(is.atomic(X) || is.atomic(v) || inherits(X, "data.frame")) TRA(X, v, "*") else
+  duplAttributes(mapply(function(x, y) TRA(x, y, "*"), unattrib(X), unattrib(v),
+                        USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%r/%" <- function(X, v) if(is.atomic(X) || is.atomic(v) || inherits(X, "data.frame")) TRA(X, v, "/") else
+  duplAttributes(mapply(function(x, y) TRA(x, y, "/"), unattrib(X), unattrib(v),
+                        USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+
+
+
+# othidentity <- function(x, y) y
+"%cr%" <- function(X, v) if(is.atomic(X)) return(duplAttributes(rep(v, NCOL(X)), X)) else # outer(rep.int(1L, dim(X)[2L]), v)
+  if(is.atomic(v)) return(duplAttributes(lapply(vector("list", length(unclass(X))), function(z) v), X)) else
+    copyAttrib(v, X) # copyAttrib first makes a shallow copy of v
+"%c+%" <- function(X, v) if(is.atomic(X)) return(X + v) else
+  duplAttributes(if(is.atomic(v)) lapply(unattrib(X), `+`, v) else
+    mapply(`+`, unattrib(X), unattrib(v), USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%c-%" <- function(X, v) if(is.atomic(X)) return(X - v) else
+  duplAttributes(if(is.atomic(v)) lapply(unattrib(X), `-`, v) else
+    mapply(`-`, unattrib(X), unattrib(v), USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%c*%" <- function(X, v) if(is.atomic(X)) return(X * v) else
+  duplAttributes(if(is.atomic(v)) lapply(unattrib(X), `*`, v) else
+    mapply(`*`, unattrib(X), unattrib(v), USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+"%c/%" <- function(X, v) if(is.atomic(X)) return(X / v) else  # or * 1L/v ??
+  duplAttributes(if(is.atomic(v)) lapply(unattrib(X), `/`, v) else
+    mapply(`/`, unattrib(X), unattrib(v), USE.NAMES = FALSE, SIMPLIFY = FALSE), X)
+
+
 
 getenvFUN <- function(nam, efmt1 = "For this method need to install.packages('%s'), then unload [detach('package:collapse', unload = TRUE)] and reload [library(collapse)].")
   if(is.null(FUN <- .collapse_env[[nam]])) stop(sprintf(efmt1, strsplit(nam, "_", fixed = TRUE)[[1L]][1L])) else FUN
 
 
+# qM2 <- function(x) if(is.list(x)) do.call(cbind, x) else x
+
 null2NA <- function(x) if(is.null(x)) NA_character_ else x
 
 # flapply <- function(x, FUN, ...) lapply(unattrib(x), FUN, ...) # not really needed ...
@@ -14,6 +55,12 @@ vlabels <- function(X, attrn = "label") {
   unlist(res)
 }
 
+# Slower on WDI !!!
+# vlabels2 <- function(X, attrn = "label") {
+#   if(is.atomic(X)) return(null2NA(attr(X, attrn)))
+#   vapply(X, function(x) if(is.null(a <- attr(x, attrn))) NA_character_ else a, character(1L))
+# }
+
 "vlabels<-" <- function(X, attrn = "label", value) {
   names(value) <- NULL
   if(is.atomic(X)) return(`attr<-`(X, attrn, value))
@@ -28,6 +75,13 @@ vlabels <- function(X, attrn = "label") {
   `oldClass<-`(X, clx)
 }
 
+# Also slower on WDI !!
+# "vlabels2<-" <- function(X, attrn = "label", value) {
+#   names(value) <- NULL
+#   if(is.atomic(X)) return(`attr<-`(X, attrn, value))
+#   duplAttributes(mapply(function(x, y) `attr<-`(x, attrn, y), `attributes<-`(X, NULL), as.vector(value, "list"),
+#                         SIMPLIFY = FALSE, USE.NAMES = FALSE), X)
+# }
 
 .c <- function(...) as.character(substitute(c(...))[-1L])
 
@@ -38,12 +92,12 @@ pasteclass <- function(x) if(length(cx <- class(x)) > 1L) paste(cx, collapse = "
 
 vclasses <- function(X) {
   if(is.atomic(X)) return(pasteclass(X))
-  vapply(X, pasteclass, character(1)) # unattrib(X): no names
+  vapply(X, pasteclass, character(1L)) # unattrib(X): no names
 }
 
 vtypes <- function(X) {
   if(is.atomic(X)) return(typeof(X))
-  vapply(X, typeof, character(1)) # unattrib(X): no names
+  vapply(X, typeof, character(1L)) # unattrib(X): no names
 }
 
 namlab <- function(X, class = FALSE, attrn = "label") {
@@ -159,8 +213,6 @@ is.Date <- function(x) inherits(x, c("Date","POSIXlt","POSIXct"))
 
 "%!in%" <- function(x, table) match(x, table, nomatch = 0L) == 0L
 
-na_rm <- function(x) x[!is.na(x)]
-
 # more consistent with base than na_rm
 # na.rm <- function(x) { # cpp version available, but not faster !
 #   if(length(attr(x, "names"))) { # gives corruped time-series !
@@ -171,6 +223,16 @@ na_rm <- function(x) x[!is.na(x)]
 #   } else duplAttributes(x[!is.na(x)], x)
 # }
 
+allNA <- function(x) .Call(C_allNA, x, TRUE) # True means give error for unsupported vector types, not FALSE.
+
+missing_cases <- function(X, cols = NULL) {
+  if(is.list(X)) return(.Call(C_dt_na, X, if(is.null(cols)) seq_along(unclass(X)) else cols2int(cols, X, attr(X, "names"))))
+  if(is.matrix(X)) return(if(is.null(cols)) !complete.cases(X) else !complete.cases(X[, cols]))
+  is.na(X)
+}
+
+na_rm <- function(x) .Call(C_na_rm, x)  # x[!is.na(x)]
+
 na_omit <- function(X, cols = NULL, na.attr = FALSE) {
   if(is.list(X)) {
     iX <- seq_along(unclass(X))
@@ -183,7 +245,9 @@ na_omit <- function(X, cols = NULL, na.attr = FALSE) {
     if(!(is.numeric(rn) || is.null(rn) || rn[1L] == "1")) attr(res, "row.names") <- rn[rkeep]
   } else {
     rl <- if(is.null(cols)) complete.cases(X) else complete.cases(X[, cols])
-    res <- if(is.matrix(X)) X[rl, , drop = FALSE] else X[rl]
+    rkeep <- which(rl)
+    if(length(rkeep) == NROW(X)) return(X)
+    res <- if(is.matrix(X)) X[rkeep, , drop = FALSE] else X[rkeep]
   }
   if(na.attr) attr(res, "na.action") <- `oldClass<-`(which(!rl), "omit")
   res
@@ -477,25 +541,5 @@ fsimplify2array <- function(l) {
 
 
 
-# Experimental:
 
-# faster pipe: more challenging than it seems...
-# `%>>%` <- function(lhs, rhs) {
-#     rhs_call <- substitute(rhs)
-#     eval(rhs_call, envir = lhs, enclos = parent.frame())
-# }
-#
-# > pipeR::`%>>%`
-# function (x, expr)
-# {
-#   x
-#   expr <- substitute(expr)
-#   envir <- parent.frame()
-#   switch(class(expr), `NULL` = NULL, character = {
-#     cat(expr, "\n")
-#     x
-#   }, `{` = pipe_dot(x, expr, envir), `(` = pipe_fun(x,
-#                                                     expr[[2L]], envir), pipe_symbol(x, expr, envir, TRUE,
-#                                                                                     pipe_first))
-# }
 
